@@ -255,7 +255,7 @@ public:
   void visit( ObjectImpVisitor* vtor ) const override;
 
   int numberOfProperties() const override;
-  const QByteArrayList properties() const override;
+  const QList<KLazyLocalizedString> properties() const override;
   const QByteArrayList propertiesInternalNames() const override;
   ObjectImp* property( int which, const KigDocument& d ) const override;
   const char* iconForProperty( int which ) const override;
